Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4834)

Unified Diff: chrome/browser/tab_contents/navigation_entry_unittest.cc

Issue 165485: Renames the NavigationEntry::display_url() to virtual_url(). (Closed)
Patch Set: Created 11 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/tab_contents/navigation_entry_unittest.cc
diff --git a/chrome/browser/tab_contents/navigation_entry_unittest.cc b/chrome/browser/tab_contents/navigation_entry_unittest.cc
index 0a9f814d01d8e1c0b70e779c1ef1da483435bfad..6f8957d9f8dd1ce5307143e52a562f1230d5d0c8 100644
--- a/chrome/browser/tab_contents/navigation_entry_unittest.cc
+++ b/chrome/browser/tab_contents/navigation_entry_unittest.cc
@@ -44,18 +44,18 @@ TEST_F(NavigationEntryTest, NavigationEntryUniqueIDs) {
// Test URL accessors
TEST_F(NavigationEntryTest, NavigationEntryURLs) {
- // Start with no display_url (even if a url is set)
- EXPECT_FALSE(entry1_.get()->has_display_url());
- EXPECT_FALSE(entry2_.get()->has_display_url());
+ // Start with no virtual_url (even if a url is set)
+ EXPECT_FALSE(entry1_.get()->has_virtual_url());
+ EXPECT_FALSE(entry2_.get()->has_virtual_url());
EXPECT_EQ(GURL(), entry1_.get()->url());
- EXPECT_EQ(GURL(), entry1_.get()->display_url());
+ EXPECT_EQ(GURL(), entry1_.get()->virtual_url());
EXPECT_TRUE(entry1_.get()->GetTitleForDisplay(NULL).empty());
// Setting URL affects display_url and GetTitleForDisplay
entry1_.get()->set_url(GURL("http://www.google.com"));
EXPECT_EQ(GURL("http://www.google.com"), entry1_.get()->url());
- EXPECT_EQ(GURL("http://www.google.com/"), entry1_.get()->display_url());
+ EXPECT_EQ(GURL("http://www.google.com/"), entry1_.get()->virtual_url());
EXPECT_EQ(ASCIIToUTF16("http://www.google.com/"),
entry1_.get()->GetTitleForDisplay(NULL));
@@ -63,13 +63,13 @@ TEST_F(NavigationEntryTest, NavigationEntryURLs) {
entry1_.get()->set_title(ASCIIToUTF16("Google"));
EXPECT_EQ(ASCIIToUTF16("Google"), entry1_.get()->GetTitleForDisplay(NULL));
- // Setting display_url doesn't affect URL
- entry2_.get()->set_display_url(GURL("display:url"));
- EXPECT_TRUE(entry2_.get()->has_display_url());
+ // Setting virtual_url doesn't affect URL
+ entry2_.get()->set_virtual_url(GURL("display:url"));
+ EXPECT_TRUE(entry2_.get()->has_virtual_url());
EXPECT_EQ(GURL("test:url"), entry2_.get()->url());
- EXPECT_EQ(GURL("display:url"), entry2_.get()->display_url());
+ EXPECT_EQ(GURL("display:url"), entry2_.get()->virtual_url());
- // Having a title set in constructor overrides display URL
+ // Having a title set in constructor overrides virtual URL
EXPECT_EQ(ASCIIToUTF16("title"), entry2_.get()->GetTitleForDisplay(NULL));
// User typed URL is independent of the others
« no previous file with comments | « chrome/browser/tab_contents/navigation_entry.cc ('k') | chrome/browser/tab_contents/render_view_context_menu.cc » ('j') | no next file with comments »
@@ -44,18 +44,18 @@ TEST_F(NavigationEntryTest, NavigationEntryUniqueIDs) {
EXPECT_TRUE(entry1_.get()->GetTitleForDisplay(NULL).empty());
- // Setting URL affects display_url and GetTitleForDisplay
+ // Setting URL affects virtual_url and GetTitleForDisplay
entry1_.get()->set_url(GURL("http://www.google.com"));
EXPECT_EQ(GURL("http://www.google.com"), entry1_.get()->url());

Powered by Google App Engine
This is Rietveld 408576698